@@ -46,7 +46,6 @@
 #include <e-util/e-autocomplete-selector.h>
 #include <e-util/e-bit-array.h>
 #include <e-util/e-book-source-config.h>
-#include <e-util/e-buffer-tagger.h>
 #include <e-util/e-cal-source-config.h>
 #include <e-util/e-calendar-item.h>
 #include <e-util/e-calendar.h>
@@ -81,12 +80,15 @@
 #include <e-util/e-client-cache.h>
 #include <e-util/e-client-combo-box.h>
 #include <e-util/e-client-selector.h>
+#include <e-util/e-collection-account-wizard.h>
 #include <e-util/e-color-chooser-widget.h>
 #include <e-util/e-color-combo.h>
+#include <e-util/e-color-scheme-watcher.h>
 #include <e-util/e-config.h>
 #include <e-util/e-config-lookup.h>
 #include <e-util/e-config-lookup-result.h>
 #include <e-util/e-config-lookup-result-simple.h>
+#include <e-util/e-config-lookup-worker.h>
 #include <e-util/e-conflict-search-selector.h>
 #include <e-util/e-contact-store.h>
 #include <e-util/e-content-editor.h>
@@ -97,6 +99,7 @@
 #include <e-util/e-destination-store.h>
 #include <e-util/e-dialog-utils.h>
 #include <e-util/e-dialog-widgets.h>
+#include <e-util/e-ellipsized-combo-box-text.h>
 #include <e-util/e-emoticon-action.h>
 #include <e-util/e-emoticon-chooser-menu.h>
 #include <e-util/e-emoticon-chooser.h>
@@ -112,6 +115,7 @@
 #include <e-util/e-filter-file.h>
 #include <e-util/e-filter-input.h>
 #include <e-util/e-filter-int.h>
+#include <e-util/e-filter-label.h>
 #include <e-util/e-filter-option.h>
 #include <e-util/e-filter-part.h>
 #include <e-util/e-filter-rule.h>
@@ -149,6 +153,8 @@
 #include <e-util/e-mail-signature-script-dialog.h>
 #include <e-util/e-mail-signature-tree-view.h>
 #include <e-util/e-map.h>
+#include <e-util/e-markdown-editor.h>
+#include <e-util/e-markdown-utils.h>
 #include <e-util/e-menu-tool-action.h>
 #include <e-util/e-menu-tool-button.h>
 #include <e-util/e-misc-utils.h>
@@ -263,8 +269,9 @@
 #include <e-util/e-util-enumtypes.h>
 #include <e-util/e-webdav-browser.h>
 #ifndef E_UTIL_INCLUDE_WITHOUT_WEBKIT
-#include <e-util/e-web-view-preview.h>
 #include <e-util/e-web-view.h>
+#include <e-util/e-web-view-jsc-utils.h>
+#include <e-util/e-web-view-preview.h>
 #endif
 #include <e-util/e-widget-undo.h>
 #include <e-util/e-xml-utils.h>
